<?php

if (substr((string) $messaggio,0,4) != "var_") {
switch ($messaggio) {

# translate YES and NO in upper case
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEE"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Dati comuni":  				$messaggio = "Standaard data"; break;
case "Utilizza i dati attuali per la connessione al database":	$messaggio = "Gebruik huidige data om met de database te verbinden"; break;
case "Utilizza altri dati per la connessione al database":	$messaggio = "Gebruik andere data om met de database te verbinden"; break;
case "Nome del database da utilizzare":  	$messaggio = "Naam van de nieuwe database"; break;
case "Nome del computer a cui collegarsi":  	$messaggio = "Naam van de computer waarmee verbonden moet worden"; break;
case "Numero della porta a cui collegarsi":  	$messaggio = "Naam van de pport waarmee verbonden moet worden"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normaal 5432 voor Postgresql of 3306 voor Mysql"; break;
case "Nome per l'autenticazione al database":  	$messaggio = "Username voor database toegang"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Password voor database toegang"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Laad de dynamische library \"pgsql.so\" of \"mysql.so\""; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nee"; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "ja als het niet automatisch door PHP wordt geladen"; break;
case "Percorso alla directory dati da dove verrà posizionato lo script":	$messaggio = "Pad naar \"dati\" folder waarheen het script wordt geplaatst"; break;
case "solo per mysql":  			$messaggio = "alleen voor mysql"; break;
case "Anno":  					$messaggio = "Jaar"; break;
case "Lingua":  				$messaggio = "Taal"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Geld formaat"; break;
case "Formato di visualizzazione delle date":  	$messaggio = "Datum formaat"; break;
case "Nome della valuta al singolare":  	$messaggio = "Enkele muntsoort naam"; break;
case "Nome della valuta al plurale":  		$messaggio = "Meervoudig geldsoort naam"; break;
case "Le date sono sbagliate":  		$messaggio = "Datums zijn verkeerd"; break;
case "Indirizzo email non valido":  		$messaggio = "Geen geldig emailadres"; break;
case "INIZIO VARIABILI MODIFICABILI":  		$messaggio = "BEGIN VAN DE WIJZIGBARE VARIABELEN"; break;
case "Inserire in questa variabile il nome della pagina se \$PHP_SELF non è definita":	$messaggio = "Voeg in deze variabele de naam in van de pagina als \$PHP_SELF niet gedefinierd is"; break;
case "europa":  				$messaggio = "europa"; break;
case "usa":  					$messaggio = "usa"; break;
case "FRASI":  					$messaggio = "ZINNEN"; break;
case "FRASI EMAIL":  				$messaggio = "EMAILZINNEN"; break;
case "PERIODI NEI MENU":  			$messaggio = "MENU PERIODEN"; break;
case "FINE VARIABILI MODIFICABILI":  		$messaggio = "EIND VAN DE WIJZIGBARE VARIABELEN"; break;
case "NON MODIFICARE NIENTE A PARTIRE DA QUI":	$messaggio = "NIETS MEER WIJZIGEN VANAF HIER"; break;
case "La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome":	$messaggio = "De \\\$PHP_SELF variable is niet gedefinieerd, U moet deze pagian handmatig editen om de naam toe te voegen"; break;
case "OK":  					$messaggio = "OK"; break;
case "Date nei menù a tendina":  		$messaggio = "Datums in drop-down menu"; break;
case "col nome":  				$messaggio = "net naam"; break;
case "Chiedere se aggiungere i costi presenti nella pagina di inserzione prenotazioni?":	$messaggio = "Vraag naar toevoegen kosten in de reserveringspagina?"; break;
case "Aggiungere al prezzo i costi aggiuntivi fissi associati alle tariffe?":	$messaggio = "Voeg toe aan de prijs de extra kosten behorend bij het gekozen tarief?"; break;
case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mostrarli":	$messaggio = "Te tonen extra kosten en de evntueel vervangende namen voor die kosten"; break;
case "Costo settimanale":  				$messaggio = "Wekelijkse kosten"; break;
case "Costo unico":  				$messaggio = "Enkel kosten"; break;
case "Costo giornaliero":  				$messaggio = "Dagelijkse kosten"; break;
case "nessuna":  				$messaggio = "geen motivering"; break;
case "comportati come se non vi fosse più disponibilità":	$messaggio = "Toon dat er geen beschikbaarheid meer is"; break;
case "dai ancora disponibilità con questa frase alternativa":	$messaggio = "Toon dat er mogelijk toch nog beschikbaarheid is met deze alternatieve zin"; break;
case "Disponibilità incerta per la tipologia scelta, per ulteriori informazioni contattateci via email":	$messaggio = "Onzekerheid over beschikbaarheid voor deze kamer, email ons voor meer informatie"; break;
case "Mostrare la caparra se presente?":  	$messaggio = "Laat deposito zien als aanwezig?"; break;
case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Laat zien welke dagen vol zijn binnen de periode waar geen beschikbaarheid meer is?"; break;
case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Toon het aanvraag reserveringsformulier?"; break;
case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Emailadres waar het verzoek tot reservering naar toe moet"; break;
case "Controlla la disponibilità":  		$messaggio = "Controleer beschikbaarheid"; break;
case "dal":  					$messaggio = "van"; break;
case "al":  					$messaggio = "tot"; break;
case "per la tipologia":  			$messaggio = "voor kamer"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "per":  					$messaggio = "voor"; break;
case "Le date sono sbagliate":  		$messaggio = "Datums zijn verkeerd"; break;
case "La tipologia è sbagliata":  		$messaggio = "Kamer is fout"; break;
case "è":  					$messaggio = "is"; break;
case "pien":  					$messaggio = "vol"; break;
case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "Er is geen beschikbaarheid meer in de gevraagde periode"; break;
case "nel periodo richiesto":			$messaggio = "in de gevraagde periode"; break;
case "nei periodi richiesti":			$messaggio = "in de gevraagde periode"; break;
case "per la tipologia":  			$messaggio = "voor kamer"; break;
case "per le tipologie richieste":		$messaggio = "voor gevraagde kamer"; break;
case "Non c'è più disponibilità":		$messaggio = "Er is geen acoomodatie meer beschikbaar"; break;
case "Periodo di":  				$messaggio = "Periode van"; break;
case "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo":	$messaggio = "Er is nog tarief voor de gevraaagde periode"; break;
case "Prezzo":  				$messaggio = "Prijs"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "compresi":  				$messaggio = "inclusief"; break;
case "di":  					$messaggio = "van"; break;
case "Nuovo controllo":  			$messaggio = "Opnieuw zoeken"; break;
case "Nome":  					$messaggio = "Naam"; break;
case "Email":  					$messaggio = "Emailadres"; break;
case "Commento":  				$messaggio = "Commentaar"; break;
case "Invia la richiesta di prenotazione":  	$messaggio = "Verstuur het verzoek voor reservering"; break;
case "Richiesta di prenotazione inviata": 	$messaggio = "Verzoek voor reservering verzonden"; break;
case "Non è stato possibile inviare la richiesta":	$messaggio = "Het was niet mogeijk het verzoek te versturen"; break;
case "da":  					$messaggio = "van"; break;
case "Periodo":  				$messaggio = "Periode"; break;
case "Tariffa":  				$messaggio = "Tarief"; break;
case "Costi aggiuntivi":  			$messaggio = "Extra kosten"; break;
case "Prezzo totale":  				$messaggio = "Totale prijs"; break;
case "Riferimento":  				$messaggio = "Referentie"; break;
case "Richesta prenotazione":  			$messaggio = "Reserveringsverzoek"; break;
case "modificare il valore sulla destra":  	$messaggio = "wijzig de waarde rechts"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "giorno":  				$messaggio = "dag"; break;
case "La":  					$messaggio = "De"; break;
case "Il":  					$messaggio = "De"; break;
case "piena":  					$messaggio = "vol"; break;
case "pieno":  					$messaggio = "vol"; break;
case "INSERISCI QUI IL TUO HTML":  		$messaggio = "VOEG UW HTML HIER IN"; break;
case "FINE DELLA PRIMA PARTE DELL'HTML PERSONALE":	$messaggio = "EINDE VAN HET EERSTE DEEL STANDAARD HTML"; break;
case "INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "BEGIN VAN HET TWEEDE DEEL VAN STANDAARD HTML"; break;
case "FINE DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "EINDE VAN HET TWEEDE DEEL VAN STANDAARD HTML"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Voorzetsel in de tabelnaam"; break;
case "Parte html del file prima della form di disponibilità":	$messaggio = "Html deel van de file voor het beschikbaarheidsformulier"; break;
case "Parte html del file dopo la form di disponibilità":	$messaggio = "Html deel van de file na het beschikbaarheidsforumulier"; break;
case "0 per scelta libera":  			$messaggio = "0 voor vrije keuze"; break;
case "Possibilità di aggiungere più tipologie da controllare contemporaneamente?":	$messaggio = "Mogelijkheid om meerdere kamers tegelijk te controlen voor beschikbaarheid?"; break;
case "Numero massimo di tipologie":  		$messaggio = "Maximum aantal kamers"; break;
case "Numero massimo di tipologie errato":  	$messaggio = "Maximum aantal kamers is verkeerd"; break;
case "Numero di":  				$messaggio = "Aantal van"; break;
case "Il numero di":  				$messaggio = "Het aantal vanaf"; break;
case "richiesto è sbagliato":  			$messaggio = "het ingevoegde is verkeerd"; break;
case "in":  					$messaggio = "in"; break;
case "Totale":  				$messaggio = "Totaal"; break;
case "Aggiungi una nuova tipologia":  		$messaggio = "Voeg een nieuwe kamer toe"; break;
case "Numero di colonne dei costi aggiuntivi errato":	$messaggio = "Het aantal van de extra kosten kolom is verkeerd"; break;
case "Numero di colonne dei costi aggiuntivi":	$messaggio = "Aantal van de extra kosten kolommen"; break;
case "tipologia":  				$messaggio = "kamer"; break;
case "Elimina questa tipologia":  		$messaggio = "Wis dit type"; break;
case "Scegliere le settimane in cui applicare":	$messaggio = "Maak een keuze voor de weken door U bedoeld"; break;
case "Scegliere i giorni in cui applicare":  	$messaggio = "Maak een keuze voor de dagen door U bedoeld"; break;
case "Chiedere il numero di persone?":  	$messaggio = "Vragen naar het aantal personen?"; break;
case "persone":  				$messaggio = "mensen"; break;
case "Persone":  				$messaggio = "Mensen"; break;
case "persona":  				$messaggio = "persoon"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "singolare":  				$messaggio = "singel"; break;
case "per ogni":  				$messaggio = "voor elk"; break;
case "Si deve inserire il numero delle persone per":	$messaggio = "Het aantal mensen moet ingevoerd worden voor"; break;
case "Errore nei servizi opzionali richiesti":	$messaggio = "Fout is gevraagde optie voor services"; break;
case "Numero massimo di persone":  		$messaggio = "Maximum aantal mensen"; break;
case "Se le persone superano la capienza massima utilizzare il costo aggiuntivo":	$messaggio = "Als het aantal personen groter is dan de maximum capaciteit gebruik de extra kosten"; break;
case "Se il costo può essere moltiplicato aggiungere al massimo":	$messaggio = "Als de kosten kunnen worden vermenigvuldigd dan maximaal"; break;
case "letti aggiuntivi":  			$messaggio = "extra bedden"; break;
case "Numero massimo di persone errato":  	$messaggio = "Verkeerd maximum aantal mensen"; break;
case "Numero massimo di letti aggiuntivi errato":	$messaggio = "Verkeerd maximum aantal extra bedden"; break;
case "supera la capienza massima della tipologia richiesta":	$messaggio = "is groter dan de maximum capaciteit voor de gevraagde kamer"; break;
case "OK":  					$messaggio = "OK"; break;
case "Modifica le frasi predefinite":  		$messaggio = "Wijzig de standaard zinnen"; break;
case "Frasi predefinite":  			$messaggio = "Standaard zinnen"; break;
case "Mostrare il quadro indicativo della disponibilità?":	$messaggio = "Beschikbaarheid grafisch laten zien?"; break;
case "Non mostrare":  				$messaggio = "Niet laten zien"; break;
case "Colore di sfondo della tabella":  	$messaggio = "Tabel achtergrond kleur"; break;
case "Colore del giorno di inizio settimana":	$messaggio = "Kleur voor dag begin van de week"; break;
case "Colore dei periodi liberi":  		$messaggio = "Vrije periode kleur"; break;
case "Colore dei periodi occupati":  		$messaggio = "Vol periode kleur"; break;
case "Tag di apertura dei font della tabella":	$messaggio = "Tabel fonts open tag"; break;
case "Tag di chiusura dei font della tabella":	$messaggio = "Tabel fonts sluit tag"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Indicatief beschibaarheids overzicht"; break;
case "Gennaio":  				$messaggio = "Januarie"; break;
case "Febbraio":  				$messaggio = "Februarie"; break;
case "Marzo":  					$messaggio = "Maart"; break;
case "Maggio":  				$messaggio = "Mei"; break;
case "Giugno":  				$messaggio = "Juni"; break;
case "Luglio":  				$messaggio = "Juli"; break;
case "Agosto":  				$messaggio = "Augustus"; break;
case "Ottobre":  				$messaggio = "Oktober"; break;
case "settimane di intervallo":  		$messaggio = "weken met interval"; break;
case "giorni di intervallo":  			$messaggio = "dagen met interval"; break;
case "Estendere l'ultima data fino a quella massima disponibile nel database?":	$messaggio = "Ga tot de laatste datum beschikbaar in de database?"; break;
case "necessario":  				$messaggio = "nodig"; break;
case "opzionale":  				$messaggio = "optioneel"; break;
case "Inviare la richiesta di prenotazione come messaggio a":	$messaggio = "Stuur het verzoek om reservering als een bericht naar"; break;
case "Campi della form da chiedere":  		$messaggio = "Te vragen formulier velden"; break;
case "Cognome":  				$messaggio = "Achternaam"; break;
case "Genere":  				$messaggio = "Geslacht"; break;
case "Data di nascita":  			$messaggio = "Geboortedatum"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "Città":  					$messaggio = "Stad"; break;
case "Regione":  				$messaggio = "Provincie"; break;
case "Via":  					$messaggio = "Straat"; break;
case "Numero civico":  				$messaggio = "Huisnummer"; break;
case "Codice postale":  			$messaggio = "Postcode"; break;
case "Telefono":  				$messaggio = "Telefoon"; break;
case "Secondo telefono":  			$messaggio = "GSM"; break;
case "Terzo telefono":  			$messaggio = "2de telefoon"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Orario stimato di arrivo":  		$messaggio = "Vermoedelijke aankomsttijd"; break;
case "Metodo di pagamento della caparra":  	$messaggio = "Deposito betaalmethode"; break;
case "Metodi di pagamento della caparra da chiedere e loro eventuali nomi sostitutivi":	$messaggio = "Deposito betaalmethoden laten zien en hun eventuele vervangende benamingen"; break;
case "Campi della form personalizzati":  	$messaggio = "Standaard formulier velden"; break;
case "tutti":  					$messaggio = "iedereen"; break;
case "M":  					$messaggio = "M"; break;
case "F":  					$messaggio = "V"; break;
case "Prenota":  				$messaggio = "Boek"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "il":  					$messaggio = "the"; break;
case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
case "Tipo di database":  			$messaggio = "Database type"; break;
case "Postgresql":  				$messaggio = "Postgresql"; break;
case "Mysql":  					$messaggio = "Mysql"; break;
case "Pagina per la disponibilità":  		$messaggio = "Availability page"; break;
case "Non ho il permesso di scrittura nella cartella":	$messaggio = "I don't have write permission on folder"; break;
case "Pagina per controllare la disponibilità":	$messaggio = "Page to check availability"; break;
case "Tariffe (tipologie) da mostrare ed eventuali loro nomi sostitutivi con cui mostrarle":	$messaggio = "Rates (types) to show and their eventual substitutive names to be shown with"; break;
case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
case "Tag html di apertura per la formattazione delle font":	$messaggio = "Opening html tag for formatting fonts"; break;
case "Tag html di chiusura per la formattazione delle font":	$messaggio = "Closing html tag for formatting fonts"; break;
case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "Opening html tag for formatting red fonts"; break;
case "Tag html di chiusura per la formattazione delle font rosse":	$messaggio = "Closing html tag for formatting red fonts"; break;
case "Crea la pagina per la disponibilità":  	$messaggio = "Create availability page"; break;
case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "The number of people is needed for this type"; break;
case "Email alternativa":  			$messaggio = "Alternative email"; break;
case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
case "settimana":  				$messaggio = "week"; break;
case "Una pagina chiamata":  			$messaggio = "A page called"; break;
case "è stata creata nella directory":  	$messaggio = "has been created in folder"; break;
case "Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"":	$messaggio = "You can change the directory where pages are created from \"configure and customize\""; break;
case "Si può creare un link verso questa pagina dal proprio sito internet":	$messaggio = "You can create a link to this page from your own internet site"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "tutte le pagine create":  		$messaggio = "all created pages"; break;
case "Si è sicuri di voler <b style=\"color: red;\">cancellare</b>":	$messaggio = "Are you sure you want to <b style=\"color: red;\">delete</b>"; break;
case "la pagina":				$messaggio = "the page"; break;
case "tutte le pagine create nella directory":	$messaggio = "every page created in directory"; break;
case "tutte le pagine create nelle directory":	$messaggio = "every page created in directories"; break;
case "Cancellate tutte le pagine":  		$messaggio = "Deleted all pages"; break;
case "Aprile":  				$messaggio = "April"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "December"; break;
case "non chiedere":  				$messaggio = "do not ask"; break;
case "Documento":  				$messaggio = "Document"; break;
case "<small>campi necessari</small>":		$messaggio = "<small>required fields</small>"; break;
case "<span style=\\\"color: red;\\\">*</span>":	$messaggio = "<span style=\\\"color: red;\\\">*</span>"; break;
case "<small>*</small>":  			$messaggio = "<small>*</small>"; break;
case "Mostrare il bottone per prenotare con la pagina di prenotazione immediata se presente?":	$messaggio = "Show the button to book with the instant booking page if present?"; break;
case "Nome file della pagina di prenotazione immediata":	$messaggio = "Instant booking page filename"; break;
case "--- OPPURE ---":  			$messaggio = "--- OR ---"; break;
case "Prenotazione istantanea con PayPal":  	$messaggio = "Instant booking with PayPal"; break;
case "Accetta solo richieste che cominciano almeno dopo":	$messaggio = "Accept only requests that begin at least after"; $tr = 1; break;
case "Numero di settimane dopo cui prendere richieste errato":	$messaggio = "Wrong number of weeks after which take requests"; $tr = 1; break;
case "Numero di giorni dopo cui prendere richieste errato":	$messaggio = "Wrong number of days after which take requests"; $tr = 1; break;
case "Mostrare i calendari per la scelta delle date?":	$messaggio = "Show the calendars to pick the dates?"; break;
case "Stile riquadro calendario":  		$messaggio = "Calendar box style"; break;
case "Stile tabella calendario":  		$messaggio = "Calendar table style"; break;
case "Stile bottoni interni":  			$messaggio = "Internal buttons style"; break;
case "Stile bottone apertura":  		$messaggio = "Opening button style"; break;
case "Colore date attive":  			$messaggio = "Active dates color"; break;
case "Colore data selezionata":  		$messaggio = "Selected date color"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "mostra":  				$messaggio = "show"; break;
case "non mostrare":  				$messaggio = "do not show"; break;
case "Inviare una copia della email di richiesta prenotazione al richiedente?":	$messaggio = "Send a copy of the reservation request email to the applier?"; break;
case "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile":	$messaggio = "We have received your reservation request and will answer as soon as possible"; break;
case "Copia della richiesta è stata inviata a":	$messaggio = "A copy of the request has been sent to"; break;
case "NON MODIFICARE MANUALMENTE":  		$messaggio = "DO NOT MODIFY BY HAND"; break;
case "Anteporre il nome della valuta?":  	$messaggio = "Put currency name in front of price?"; break;
case "Stile della tabella che racchiude la form di prenotazione":	$messaggio = "Style of the table that encloses the booking form"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Align availability with arrival date?"; break;
case "Origine della prenotazione":  		$messaggio = "Reservation origin"; break;
case "Cartella":  				$messaggio = "Directory"; break;
case "Pagina cancellata":  			$messaggio = "Page deleted"; break;
case "Importa le pagine dalla cartella":  	$messaggio = "Import pages from directory"; break;
case "alla cartella":  				$messaggio = "to directory"; break;
case "Importa":  				$messaggio = "Import"; break;
case "Si è sicuri di voler importare le pagine dalla cartella":	$messaggio = "Are you sure you want to import pages from directory"; break;
case "eventuali pagine già presenti nella cartella":	$messaggio = "pages eventually already present in directory"; break;
case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "will be <b style=\"font-weight: normal; color: red;\">overwritten</b>"; break;
case "Pagine importate":  			$messaggio = "Pages imported"; break;
case "con i servizi opzionali selezionati":  	$messaggio = "with selected optional services"; break;
case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
case "html personalizzato":  			$messaggio = "custom html"; break;
case "il tema chiamato":  			$messaggio = "the theme called"; break;
case "Colore del tema":  			$messaggio = "Color of theme"; break;
case "Data di arrivo":  			$messaggio = "Arrival date"; break;
case "Data di partenza":  			$messaggio = "Departure date"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
case "Accetto":  				$messaggio = "I accept"; break;
case "documento":  				$messaggio = "document"; break;
case "larghezza":  				$messaggio = "width"; break;
case "altezza":  				$messaggio = "height"; break;
case "Dalla modalidà frame, aprire il secondo passo in una nuova finestra?":	$messaggio = "From framed mode, open second step in new window?"; break;
case "Geometria della nuova finestra":  	$messaggio = "New window geometry"; break;
case "Torna alla HOME":  			$messaggio = "Back to HOME"; break;
case "URL della home":  			$messaggio = "Home URL"; break;
case "URL del logo":  				$messaggio = "Logo URL"; break;
case "Valore del tema":  			$messaggio = "Value of theme"; break;
case "Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito":	$messaggio = "Example of html code to include te first step of the form in framed mode on other website pages"; break;
case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "select \"custom html\" in page appearance to modify it"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
case "aggiunto al commento":  			$messaggio = "added to comment"; break;
case "aggiunto al campo":  			$messaggio = "added to field"; break;
case "del cliente":  				$messaggio = "in client data"; break;
case "URL file css":  				$messaggio = "URL of css file"; break;
case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "mai":  					$messaggio = "never"; break;
case "se possibile":  				$messaggio = "when possible"; break;
case "sempre":  				$messaggio = "always"; break;
case "posizioni vicine":  			$messaggio = "nearby positions"; break;
case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
case "sicuro":  				$messaggio = "secure"; break;
case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
case "Il codice":  				$messaggio = "The code"; break;
case "aggiunge":  				$messaggio = "adds"; break;
case "rimuove":  				$messaggio = "removes"; break;
case "Codice promozionale":  			$messaggio = "Promotional code"; break;
case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
case "titolo html":  				$messaggio = "html title"; break;
case "titolo":  				$messaggio = "title"; break;
case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Raggruppamento":  			$messaggio = "Grouping"; break;
case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
case "Seconda email":  				$messaggio = "Second email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
case "notte":  					$messaggio = "night"; break;
case "notti":  					$messaggio = "nights"; break;
case "cambia date":  				$messaggio = "change dates"; break;
case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
case "Secondo cognome":  			$messaggio = "Second surname"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# NAME OF THE FILE: same rules as varibles below
case "mdl_disponibilita":  			$messaggio = "beschikbaarheids_mlp"; break;

} # fine switch ($messaggio)
} # fine if (substr((string) $messaggio,0,4) != "var_")


else {
switch ($messaggio) {

# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only ASCII a-z, A-Z, 0-9 
# and _ (underscore). No spaces, no accents! No special characters! There must not be 2 with the same name.
# NOTE: names of variables are only shown when editing files, actually *they don't need to be translated*
case "var_fr_con_i_servizi_opzionali_selezionati":	$messaggio = "var_with_selected_optional_services"; break;

case "var_nome_pagina":  			$messaggio = "var_page_name"; break;
case "var_anno":  				$messaggio = "var_year"; break;
case "var_tipo_db":  				$messaggio = "var_db_type"; break;
case "var_nome_db":  				$messaggio = "var_db_name"; break;
case "var_computer_db":  			$messaggio = "var_db_host"; break;
case "var_porta_db":  				$messaggio = "var_db_port"; break;
case "var_utente_db":  				$messaggio = "var_db_user"; break;
case "var_password_db":  			$messaggio = "var_db_password"; break;
case "var_carica_estensione_db":  		$messaggio = "var_db_load_extension"; break;
case "var_prefisso_tabelle_db":  		$messaggio = "var_db_tables_prefix"; break;
case "var_lingua_modello":  			$messaggio = "var_template_language"; break;
case "var_cartella_mysql_lock":  		$messaggio = "var_mysql_lock_dir"; break;
case "var_stile_soldi":  			$messaggio = "var_money_format"; break;
case "var_stile_data":  			$messaggio = "var_dates_format"; break;
case "var_anteponi_nome_valuta":  		$messaggio = "var_currency_name_in_front"; break;
case "var_utente_liste":  			$messaggio = "var_lists_user"; break;
case "var_estendi_ultima_data":  		$messaggio = "var_extend_last_date"; break;
case "var_tariffe_mostra":  			$messaggio = "var_rates_to_show"; break;
case "var_nomi_tariffe_imposte":  		$messaggio = "var_imposed_rates_names"; break;
case "var_aggiungi_costi_fissi":  		$messaggio = "var_add_extra_costs"; break;
case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_ask_for_extra_costs_in_insertion_page"; break;
case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
case "var_nomi_costi_agg_imposti":  		$messaggio = "var_imposed_extra_costs_names"; break;
case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
case "var_assegna_con_regola2":  		$messaggio = "var_assign_with_rule1"; break;
case "var_considera_motivazioni_regola1":  	$messaggio = "var_motivations_of_rule1_to_consider"; break;
case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternative_phrase_for_rule1"; break;
case "var_mostra_caparra":  			$messaggio = "var_show_deposit"; break;
case "var_mostra_richiesta_via_mail":  		$messaggio = "var_show_request_by_mail"; break;
case "var_indirizzo_email":  			$messaggio = "var_email_address"; break;
case "var_mostra_giorni_pieni":  		$messaggio = "var_show_full_days"; break;
case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
case "var_origine_prenotazione":  		$messaggio = "var_reservation_origin"; break;
case "var_apertura_tag_font":  			$messaggio = "var_font_tag_opening"; break;
case "var_chiusura_tag_font":  			$messaggio = "var_font_tag_closing"; break;
case "var_apertura_tag_font_rosse":  		$messaggio = "var_red_font_tag_opening"; break;
case "var_chiusura_tag_font_rosse":  		$messaggio = "var_red_font_tag_closing"; break;
case "var_chiedi_numero_persone":  		$messaggio = "var_ask_people_number"; break;
case "var_periodi_no_richieste":		$messaggio = "var_periods_no_requests"; break;
case "var_mostra_calendario_scelta_date":  	$messaggio = "var_show_dates_picker_calendar"; break;
case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style"; break;
case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
case "var_fr_Valuta_sing":  			$messaggio = "var_phr_Currency_sing"; break;
case "var_fr_Valuta_plur":  			$messaggio = "var_phr_Currency_plur"; break;
case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_phr_Check_availability"; break;
case "var_fr_dal":  				$messaggio = "var_phr_from"; break;
case "var_fr_al":  				$messaggio = "var_phr_to"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_phr_for_type"; break;
case "var_fr_tariffa":  			$messaggio = "var_phr_rate"; break;
case "var_fr_per":  				$messaggio = "var_phr_for"; break;
case "var_fr_Le_date_sono_sbagliate":  		$messaggio = "var_phr_Dates_are_wrong"; break;
case "var_fr_La_tipologia_e_sbagliata":  	$messaggio = "var_phr_Type_is_wrong"; break;
case "var_fr_parola_La":  			$messaggio = "var_phr_word_the"; break;
case "var_fr_parola_settimana":  		$messaggio = "var_phr_word_week"; break;
case "var_fr_est":  				$messaggio = "var_phr_is"; break;
case "var_fr_pien":  				$messaggio = "var_phr_full"; break;
case "var_fr_lettera_a":  			$messaggio = "var_phr_letter_sing_fem"; break;
case "var_fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto":	$messaggio = "var_phr_There_is_not_availability_anymore_in_the_requested_period"; break;
case "var_fr_C_e_ancora_disponibilita":  	$messaggio = "var_phr_There_is_still_availability"; break;
case "var_fr_Non_c_e_piu_disponibilita":  	$messaggio = "var_phr_There_is_not_availability_anymore"; break;
case "var_fr_alternativa_regola1":  		$messaggio = "var_phr_rule1_alternative"; break;
case "var_fr_Periodo_di":  			$messaggio = "var_phr_Period_of"; break;
case "var_fr_parola_settimane":  		$messaggio = "var_phr_word_weeks"; break;
case "var_fr_Non_c_e_tariffa_per_questa_tipologia_ecc":	$messaggio = "var_phr_There_is_still_not_rate_for_the_requested_type_etc"; break;
case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_The_number_of_people_is_needed_etc"; break;
case "var_fr_Prezzo":  				$messaggio = "var_phr_Price"; break;
case "var_fr_Caparra":  			$messaggio = "var_phr_Deposit"; break;
case "var_fr_compresi":  			$messaggio = "var_phr_including"; break;
case "var_fr_di":  				$messaggio = "var_phr_of"; break;
case "var_fr_Nuovo_controllo":  		$messaggio = "var_phr_New_check"; break;
case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
case "var_fr_Commento":  			$messaggio = "var_phr_Comment"; break;
case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_phr_Send_the_request_for_reservation"; break;
case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_phr_It_was_not_possible_to_send_the_request"; break;
case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
case "var_fre_Commento":  			$messaggio = "var_phre_Comment"; break;
case "var_fre_Periodo":  			$messaggio = "var_phre_Period"; break;
case "var_fre_dal":  				$messaggio = "var_phre_from"; break;
case "var_fre_al":  				$messaggio = "var_phre_to"; break;
case "var_fre_Tariffa":  			$messaggio = "var_phre_Rate"; break;
case "var_fre_Costi_aggiuntivi":  		$messaggio = "var_phre_Extra_costs"; break;
case "var_fre_sett":  				$messaggio = "var_phre_weeks"; break;
case "var_fre_Prezzo_totale":  			$messaggio = "var_phre_Total_price"; break;
case "var_fre_Riferimento":  			$messaggio = "var_phre_Reference"; break;
case "var_fre_Caparra":  			$messaggio = "var_phre_Deposit"; break;
case "var_fre_Richesta_prenotazione":  		$messaggio = "var_phre_Reservation_request"; break;
case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
case "var_periodi_menu":  			$messaggio = "var_menu_periods"; break;
case "var_fr_appartamenti":  			$messaggio = "var_phr_apartments"; break;
case "var_fr_appartamento":  			$messaggio = "var_phr_apartment"; break;
case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_ask_number_apartments_for_type"; break;
case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximum_number_apartments_for_type"; break;
case "var_aggiungi_altre_tipologie":  		$messaggio = "var_add_other_types"; break;
case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximum_number_other_types"; break;
case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
case "var_fr_Numero_di":  			$messaggio = "var_phr_Number_of"; break;
case "var_fr_Il_numero_di":  			$messaggio = "var_phr_The_number_of"; break;
case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_phr_inserted_is_wrong"; break;
case "var_fr_in":  				$messaggio = "var_phr_in"; break;
case "var_fr_Totale":  				$messaggio = "var_phr_Total"; break;
case "var_fre_Numero_di_appartamenti":  	$messaggio = "var_phre_Number_of_apartments"; break;
case "var_fre_Persone":  			$messaggio = "var_phre_People"; break;
case "var_fr_Aggiungi_una_nuova_tipologia":	$messaggio = "var_phr_Add_a_new_type"; break;
case "var_numero_colonne_costi_aggiuntivi":  	$messaggio = "var_extra_costs_columns_number"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_phr_for_type"; break;
case "var_fr_per_le_tipologie_richieste":  	$messaggio = "var_phr_for_requested_types"; break;
case "var_fr_nel_periodo_richiesto":  		$messaggio = "var_phr_in_the_requested_period"; break;
case "var_fr_nei_periodi_richiesti":  		$messaggio = "var_phr_in_the_requested_periods"; break;
case "var_fr_tipologia":  			$messaggio = "var_phr_type"; break;
case "var_fr_Torna_indietro":  			$messaggio = "var_phr_Go_back"; break;
case "var_fr_Elimina_questa_tipologia":  	$messaggio = "var_phr_Delete_this_type"; break;
case "var_fr_Scegliere_le_settimane_in_cui_applicare":	$messaggio = "var_phr_Choose_the_weeks_to_be_applied_for"; break;
case "var_fr_persone":  			$messaggio = "var_phr_people"; break;
case "var_fr_persona":  			$messaggio = "var_phr_person"; break;
case "var_fr_Continua":  			$messaggio = "var_phr_Continue"; break;
case "var_fr_per_ogni":  			$messaggio = "var_phr_for_each"; break;
case "var_fr_Si_deve_inserire_il_numero_delle_persone_per":	$messaggio = "var_phr_The_number_of_people_must_be_inserted_for"; break;
case "var_fr_Errore_nei_servizi_opzionali_richiesti":	$messaggio = "var_phr_Error_in_requested_optional_services"; break;
case "var_massimo_numero_persone":  		$messaggio = "var_maximum_number_people"; break;
case "var_costo_aggiungi_letti":  		$messaggio = "var_cost_add_beds"; break;
case "var_massimo_numero_letti_aggiuntivi":  	$messaggio = "var_maximum_number_extra_beds"; break;
case "var_fr_supera_la_capienza_massima_della_tipologia_richiesta":	$messaggio = "var_phr_is_bigger_than_the_maximum_capacity_of_requested_type"; break;
case "var_mostra_quadro_disponibilita":  	$messaggio = "var_show_availability_overview"; break;
case "var_raggruppa_quadro_disponibilita_con_regola_2":	$messaggio = "var_group_availability_overview_with_rule_2"; break;
case "var_raggruppa_quadro_disponibilita_con_persone":	$messaggio = "var_group_availability_overview_with_people"; break;
case "var_colore_sfondo_quadro_disponibilita":	$messaggio = "var_background_color_availability_overview"; break;
case "var_colore_inizio_settimana_quadro_disponibilita":	$messaggio = "var_color_week_beginning_availability_overview"; break;
case "var_colore_libero_quadro_disponibilita":	$messaggio = "var_color_free_availability_overview"; break;
case "var_colore_occupato_quadro_disponibilita":	$messaggio = "var_color_full_availability_overview"; break;
case "var_apertura_font_quadro_disponibilita":	$messaggio = "var_opening_font_availability_overview"; break;
case "var_chiusura_font_quadro_disponibilita":	$messaggio = "var_closing_font_availability_overview"; break;
case "var_mostra_numero_liberi_quadro_disponibilita":	$messaggio = "var_show_free_number_availability_overview"; break;
case "var_fr_Quadro_indicativo_disponibilita":	$messaggio = "var_phr_Indicative_availability_overview"; break;
case "var_fr_Gennaio":  			$messaggio = "var_phr_January"; break;
case "var_fr_Febbraio":  			$messaggio = "var_phr_February"; break;
case "var_fr_Marzo":  				$messaggio = "var_phr_March"; break;
case "var_fr_Aprile":  				$messaggio = "var_phr_April"; break;
case "var_fr_Maggio":  				$messaggio = "var_phr_May"; break;
case "var_fr_Giugno":  				$messaggio = "var_phr_June"; break;
case "var_fr_Luglio":  				$messaggio = "var_phr_July"; break;
case "var_fr_Agosto":  				$messaggio = "var_phr_August"; break;
case "var_fr_Settembre":  			$messaggio = "var_phr_September"; break;
case "var_fr_Ottobre":  			$messaggio = "var_phr_October"; break;
case "var_fr_Novembre":  			$messaggio = "var_phr_November"; break;
case "var_fr_Dicembre":  			$messaggio = "var_phr_December"; break;
case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
case "var_chiedi_nazione":  			$messaggio = "var_ask_nation"; break;
case "var_chiedi_citta":  			$messaggio = "var_ask_city"; break;
case "var_chiedi_regione":  			$messaggio = "var_ask_region"; break;
case "var_chiedi_via":  			$messaggio = "var_ask_street"; break;
case "var_chiedi_numcivico":  			$messaggio = "var_ask_housenumber"; break;
case "var_chiedi_cap":  			$messaggio = "var_ask_postalcode"; break;
case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
case "var_fr_Genere":  				$messaggio = "var_phr_Gender"; break;
case "var_fr_Data_di_nascita":  		$messaggio = "var_phr_Birthdate"; break;
case "var_fr_Documento":  			$messaggio = "var_phr_Document"; break;
case "var_fr_Nazione":  			$messaggio = "var_phr_Nation"; break;
case "var_fr_Citta":  				$messaggio = "var_phr_City"; break;
case "var_fr_Regione":  			$messaggio = "var_phr_Region"; break;
case "var_fr_Via":  				$messaggio = "var_phr_Street"; break;
case "var_fr_Numero_civico":  			$messaggio = "var_phr_House_number"; break;
case "var_fr_Codice_postale":  			$messaggio = "var_phr_Postal_code"; break;
case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
case "var_fre_Data_di_nascita":  		$messaggio = "var_phre_Birthdate"; break;
case "var_fre_Documento":  			$messaggio = "var_phre_Document"; break;
case "var_fre_Nazione":  			$messaggio = "var_phre_Nation"; break;
case "var_fre_Citta":  				$messaggio = "var_phre_City"; break;
case "var_fre_Regione":  			$messaggio = "var_phre_Region"; break;
case "var_fre_Via":  				$messaggio = "var_phre_Street"; break;
case "var_fre_Numero_civico":  			$messaggio = "var_phre_House_number"; break;
case "var_fre_Codice_postale":  		$messaggio = "var_phre_Postal_code"; break;
case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
case "var_fr_piena":  				$messaggio = "var_phr_full"; break;
case "var_fr_asterisco_rosso":  		$messaggio = "var_phr_red_asterisk"; break;
case "var_fr_asterisco_nero":  			$messaggio = "var_phr_black_asterisk"; break;
case "var_fr_maschile":  			$messaggio = "var_phr_male"; break;
case "var_fr_femminile":  			$messaggio = "var_phr_female"; break;
case "var_fr_Prenota":  			$messaggio = "var_phr_Book"; break;
case "var_fr_OPPURE_linee":  			$messaggio = "var_fr_OR_dashes"; break;
case "var_fr_Prenotazione_istantanea_con_PayPal":	$messaggio = "var_fr_Instant_booking_with_PayPal"; break;
case "var_fr_Chiudi":  				$messaggio = "var_phr_Close"; break;
case "var_manda_copia_richiesta_email":  	$messaggio = "var_send_copy_of_request_email"; break;
case "var_fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc":	$messaggio = "var_phr_We_have_received_your_reservation_request_etc"; break;
case "var_fr_Copia_della_richiesta_e_stata_inviata_a":	$messaggio = "var_phr_A_copy_of_the_request_has_been_sent_to"; break;
case "var_fr_Data_di_arrivo":  			$messaggio = "var_phr_Arrival_date"; break;
case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
case "var_fr_notte":  				$messaggio = "var_phr_night"; break;
case "var_fr_notti":  				$messaggio = "var_phr_nights"; break;
case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
} # fine switch ($messaggio)
} # fine else if (substr((string) $messaggio,0,4) != "var_")



?>
